import './dep111.js';
export { x } from './dep112.js';
console.log('11');
